getHapmapExperiment <- function(pathToCelFiles){
	if(missing(pathToCelFiles)) stop("must specify complete path to HapMap phase 3 CEL files")
	phenodata <- mergeHapMapExtData() ## for parents	
	celFiles <- list.celfiles(pathToCelFiles,  full.names=TRUE, pattern=".CEL")
	celFiles <- celFiles[match(phenodata$V2, basename(celFiles))]
	stopifnot(all.equal(basename(celFiles), phenodata$V2))
	phenodata$celFiles <- celFiles
	phenodata$dates <- sapply(celFiles, celfileDate)
	phenodata$plate <- substr(basename(celFiles), 1, 5)
	message("Excluding dates for which fewer than 15 samples were processed.")
	smallNs <- names(table(as.factor(phenodata$dates)))[table(as.factor(phenodata$dates)) < 15]
	sample.index <- which(!phenodata$dates %in% smallNs)				
	phenodata <- phenodata[sample.index, ]
	return(phenodata)
}

mergeHapMapExtData <- function(){
	path <- system.file("extdata", package="NGbatch")
	fname <- file.path(path, "passing_cels_sample_map.txt")
	passing_cels_sample_map <- read.delim(fname, as.is=TRUE, header=FALSE)
	tmp <- passing_cels_sample_map

	fname <- file.path(path, "relationships_w_pops_121708.txt")
	relationships_w_pops <- read.delim(fname, as.is=TRUE, header=TRUE)
	
	pops <- relationships_w_pops
	merged <- merge(pops, tmp, by.x="IID", by.y=1)
	merged$plate <- substr(merged$V2, 1, 5)

	offspring <- merged$V2[which(merged$dad !=0 | merged$mom !=0)]
	dups <- merged$V2[grep("redo", merged$V2)]
	removeSamples <- c(offspring, dups)
	merged <- merged[!merged$V2 %in% removeSamples, ]
	return(merged)
}

getBipolarExperiment <- function(pathToCelFiles){
	celFiles <- list.celfiles(pathToCelFiles, full.names=TRUE, pattern=".CEL") ##2658
	dup.index <- grep("dup", celFiles)
	plate <- substr(basename(celFiles), 7,11)
	plate[dup.index] <- substr(basename(celFiles)[dup.index], 11, 15)
	dates <- sapply(celFiles, celfileDate)
	names(dates) <- basename(names(dates))
	stopifnot(all.equal(names(dates), basename(celFiles)))
	## drop dates with small numbers of samples
	smallNs <- names(table(as.factor(dates)))[table(as.factor(dates)) < 15]
	sample.index <- which(!dates %in% smallNs)
	celFiles <- celFiles[sample.index]
	plate <- plate[sample.index]
	dates <- dates[sample.index]
	bipolarStatus <- rep(NA, length(celFiles))
	bipolarStatus[grep("BARD-EA", celFiles)] <- 1L
	bipolarStatus[grep("GRU-EA", celFiles)] <- 0L	
	phenodata <- as.data.frame(list(celFiles=celFiles,
					bipolarStatus=bipolarStatus,
					plate=plate,
					dates=dates))
	phenodata$celFiles <- as.character(phenodata$celFiles)
	return(phenodata)
}


