###################################################
### chunk number 1: packages
###################################################
library(NGbatch)


###################################################
### chunk number 2: bipolarSetup
###################################################
path <- paste("/thumper/ctsa/snpmicroarray/GAIN/Bipolar", c("BARD-EA", "GRU-EA"), sep="/")
outdir <- "/amber1/scratch/rscharpf/NGbatch/bipolar"
dir.create(outdir, recursive=TRUE, showWarnings=FALSE)
ldPath(outdir)
bipolarExp <- getBipolarExperiment(path)


###################################################
### chunk number 3: preprocessBipolar
###################################################
if(!exists("bipolarSet")){
	if(!file.exists(file.path(outdir, "bipolarSet.rda"))){
		path <- system.file("extdata", package="NGbatch")
		load(file.path(path, "featureData.rda"))
		A <- initializeBigMatrix("A", nr=nrow(featureData), nc=length(bipolarExp$celFiles))
		rownames(A) <- featureNames(featureData)
##		trace(processCEL2, browser)
		crlmm:::cnrma2(A=A, filenames=bipolarExp$celFiles, row.names=featureNames(featureData),
 			       cdfName="genomewidesnp6")		
		bipolarSet <- new("ExpressionSet", 
				  exprs=A,
				  featureData=featureData)
		bipolarSet$dates <- bipolarExp$dates
		bipolarSet$bipolarStatus <- bipolarExp$bipolarStatus
		save(bipolarSet,file=file.path(outdir, "bipolarSet.rda"))
		q("no")
	} else {
		message("load bipolarSet")
		load(file.path(outdir, "bipolarSet.rda"))
	}
}


###################################################
### chunk number 4: association_bipolar
###################################################
ymat <- model.matrix(~ as.factor(bipolarSet$dates))
gmat <- model.matrix(~ as.factor(bipolarSet$bipolarStatus))
coeffRV(ymat,gmat)$rv ## 0.2916


###################################################
### chunk number 5: Fs_bipolar
###################################################
X <- A(bipolarSet)
lX <- log(X)
setMethod("A", "ExpressionSet", function(object) exprs(object))
if(!exits("Fs_bipolar")){
	if(!file.exists(file.path(outdir, "Fs_bipolar.rda"))){
		Fs_bipolar <- rowFtests(lX, as.factor(eset$dates))
		save(Fs_bipolar, file=file.path(outdir, "Fs_bipolar.rda"))
	} else {
		message("Loading saved F-statistics")
		load(file.path(outdir, "Fs_bipolar.rda"))
	}
}


###################################################
### chunk number 6: svd_bipolar
###################################################
if(!exists("Vs_bipolar")){
	if(!file.exists(file.path(outdir, "Vs_bipolar.rda"))){
		lX.center <- sweep(lX, 1, rowMeans(lX))
		svdResult <- fast.svd(lX.center)
		Vs_bipolar <- svdResult$v[, 1:5]
		save(Vs_bipolar, file=file.path(outdir, paste("Vs_bipolar.rda", sep="")))
	} else {
		message("Loading the Vs")
		load(file.path(outdir, "Vs_bipolar.rda"))
	}
}


