###################################################
### chunk number 1: packages
###################################################
library(ff)
library(NGbatch)
library(genefilter)
library(FactoMineR)


###################################################
### chunk number 2: setup
###################################################
##outdir <- "/amber1/scratch/rscharpf/hapmap/phase3"
outdir <- "/amber1/scratch/rscharpf/NGbatch"
if(!file.exists(outdir)) dir.create(outdir)
ldPath(outdir)
phenodata <- mergeHapMapExtData() ## for parents
celFiles <- list.celfiles("/thumper/ctsa/snpmicroarray/hapmap/raw/affy/phase3_1m",  full.names=TRUE, pattern=".CEL")
celFiles <- celFiles[match(phenodata$V2, basename(celFiles))]
stopifnot(all.equal(basename(celFiles), phenodata$V2))
phenodata$celFiles <- celFiles
phenodata$dates <- sapply(celFiles, celfileDate)
phenodata$plate <- substr(basename(celFiles), 1, 5)
smallNs <- names(table(as.factor(phenodata$dates)))[table(as.factor(phenodata$dates)) < 15]
sample.index <- which(!phenodata$dates %in% smallNs)				
phenodata <- phenodata[sample.index, ]


###################################################
### chunk number 3: preprocess
###################################################
if(!exists("eset")){
	if(!file.exists(file.path(outdir, "eset.rda"))){
		cnSet <- genotype2(phenodata$celFiles, cdfName="genomewidesnp6", 
				   copynumber=TRUE, batch=phenodata$plate)
		marker.index <- which(!isSnp(cnSet))
		A <- A(cnSet)[marker.index, ]
		eset <- new("ExpressionSet", 
			    exprs=A,
			    phenoData=phenoData(cnSet),
			    featureData=featureData(cnSet)[marker.index, ],
			    protocolData=protocolData(cnSet))
		eset$dates <- phenodata$dates
		eset$population <- phenodata$population
		save(eset, file=file.path(outdir, "eset.rda"))
		q("no")
	} else {
		message("Loading eset")
		load(file.path(outdir, "eset.rda"))
	}
}


###################################################
### chunk number 4: pops
###################################################
ymat <- model.matrix(~ as.factor(eset$dates))
gmat <- model.matrix(~ as.factor(eset$population))
coeffRV(ymat,gmat)$rv ## 0.2754


###################################################
### chunk number 5: Fs
###################################################
if(!exits("Fs")){
	Fs <- rowFtests(A(eset), as.factor(eset$dates))
}


