# make sure it's version 0.6.3 of Rsge library
# you might have to install it
library(Rsge)

# running example: computing row means
A <- matrix(rnorm(12), nr=4)
apply(A,1,mean)

# run locally through Rsge
sge.apply(A,1,mean,cluster=FALSE)

# run in cluster
sge.apply(A,1,mean)

# did it in one job (it tries to be smart about how many jobs to use)
# use one job per row
sge.apply(A,1,mean,njobs=4)

# how to keep files around
sge.options(sge.remove.files=FALSE)
sge.apply(A,1,mean,njobs=4)

# data
list.files(pattern="^Rsge")

# error and output files written by sge
list.files(pattern="^RunSge")

# let's remove them
file.remove(list.files(pattern="^Rsge"))
file.remove(list.files(pattern="^RunSge"))

sge.options(sge.remove.files=TRUE)

# another example: solve a few linear systems
B <- matrix(runif(12), nr=4)
qr.solve(B,A)

# using apply
apply(A, 2, function(a) qr.solve(B,a))

# run locally through Rsge
sge.apply(A, 2, function(a) qr.solve(B,a), cluster=FALSE)

# run on cluster
sge.apply(A, 2, function(a) qr.solve(B,a), njobs=2)

# oops it has to find B somehow
sge.apply(A, 2, function(a) qr.solve(B,a), global.savelist=c("B"), njobs=2)

# how to pass options
sge.options(sge.qsub.options="-cwd -V -l mem_free=2G")
sge.apply(A, 2, function(a) qr.solve(B,a), global.savelist=c("B"), njobs=2)

sessionInfo()
